#
# spec file for package python-xarray-einstats
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == ""
%define psuffix %{nil}
%bcond_with test
%else
%bcond_without test
%define psuffix -%{flavor}
%if "%{flavor}" == "test-numba"
%bcond_without numba
%else
%bcond_with numba
%endif
%endif

%{?sle15_python_module_pythons}
Name:           python-xarray-einstats%{psuffix}
Version:        0.8.0
Release:        1.3
Summary:        Stats, linear algebra and einops for xarray
License:        Apache-2.0
URL:            https://github.com/arviz-devs/xarray-einstats
Source:         https://github.com/arviz-devs/xarray-einstats/archive/refs/tags/v%{version}.tar.gz#/xarray-einstats-%{version}-gh.tar.gz
BuildRequires:  %{python_module base >= 3.10}
BuildRequires:  %{python_module flit-core}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
Requires:       python-numpy >= 1.23
Requires:       python-scipy >= 1.8
Requires:       python-xarray >= 2022.9.0
%if %{with test}
%if %{with numba}
# Numba requires numpy < 2.1, numba is optional, don't pin numpy in runtime requirements!
BuildRequires:  %{python_module numba}
%endif
BuildRequires:  %{python_module hypothesis}
BuildRequires:  %{python_module packaging}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module xarray-einstats = %{version}}
%endif
# /SECTION
%python_subpackages

%description
Stats, linear algebra and einops for xarray

%prep
%autosetup -p1 -n xarray-einstats-%{version}

%if !%{with test}
%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
donttest="dummyprefix"
# no python-einops in TW
ignoretests="--ignore tests/test_einops.py"
%if %{with numba}
# expects numpy 2.1 behavior, see comment above
donttest="$donttest or test_pinv"
%else
ignoretests="$ignoretests --ignore tests/test_numba.py"
%endif
%pytest $ignoretests -k "not (${donttest})"
%endif

%if !%{with test}
%files %{python_files}
%license LICENSE
%{python_sitelib}/xarray_einstats
%{python_sitelib}/xarray_einstats-%{version}*-info
%endif

%changelog
* Sat Sep 21 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.8.0
  * Add numpy.linalg.pinv wrapper PR#63
  * Update to handle modified behaviour of numpy.linalg.solve PR#63
- Add multibuild: Test with current numpy and with numba compatible
  numpy < 2.1
* Thu Sep  5 2024 Ben Greiner <code@bnavigator.de>
- Pin numpy < 2 in testing, due to numba
* Sat Mar  2 2024 Ben Greiner <code@bnavigator.de>
- Skip python39: no xarray anymore
* Mon Feb 12 2024 Daniel Garcia <daniel.garcia@suse.com>
- Enable again numba tests for python >= 3.11
* Sun Jan 21 2024 Dirk Müller <dmueller@suse.com>
- update to 0.7.0:
  * Add support for hashable dimension names
  * Fix tests to be compatible with latest xarray
  * Address numpy deprecation warnings
  * `.ecdf` now returns a DataArray to be compatible with
    `~xarray.Dataset.map` {pull}`47`
  * Added `.linalg` and `.einops` accessors for `DataArray`
    objects
  * Update dependencies and follow new pylint recommendations
  * Add documentation showing how to use accessors
  * Ease running einops tutorial locally
* Fri Mar 24 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.5.1
  * Fix lower cap on xarray version dependency #45
- Release v0.5.0
  * Added {func}.empty_ref, {func}.ones_ref and {func}.zeros_ref
    DataArray creation helpers #37
  * Added {func}.linalg.diagonal wrapper #37
  * Added {func}.stats.logsumexp wrapper #40
  * Added {func}.searchsorted and {func}.ecdf in
    {mod}~xarray_einstats.numba module #40
  * Added {func}~xarray_einstats.sort wrapper for vectorized sort
    along specific dimension using values #40
  * Fix issue in linalg.svd for non-square matrices #37
  * Fix evaluation of distribution methods (e.g. .pdf) on scalars
    [#38] and #39
  * Ensure support on inputs with stacked dimensions #40
- Release v0.4.0
  * Add multivariate_normal distribution class #23
  * Update pyproject.toml to support building the package with both
    flit and setuptools #26
  * Update python and dependency versions #33
* Thu Nov 24 2022 Dirk Müller <dmueller@suse.com>
- add LICENSE
* Wed Nov 23 2022 Daniel Garcia <daniel.garcia@suse.com>
- Initial version
